==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/VirtualMachineNetworkInterfaceConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Describes a virtual machine network interface configurations.
 * @property deleteOption Specify what happens to the network interface when the VM is deleted
 * @property disableTcpStateTracking Specifies whether the network interface is disabled for tcp state tracking.
 * @property dnsSettings The dns settings to be applied on the network interfaces.
 * @property dscpConfiguration
 * @property enableAcceleratedNetworking Specifies whether the network interface is accelerated networking-enabled.
 * @property enableFpga Specifies whether the network interface is FPGA networking-enabled.
 * @property enableIPForwarding Whether IP forwarding enabled on this NIC.
 * @property ipConfigurations Specifies the IP configurations of the network interface.
 * @property name The network interface configuration name.
 * @property networkSecurityGroup The network security group.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 */
public data class VirtualMachineNetworkInterfaceConfigurationResponse(
    public val deleteOption: String? = null,
    public val disableTcpStateTracking: Boolean? = null,
    public val dnsSettings: VirtualMachineNetworkInterfaceDnsSettingsConfigurationResponse? = null,
    public val dscpConfiguration: SubResourceResponse? = null,
    public val enableAcceleratedNetworking: Boolean? = null,
    public val enableFpga: Boolean? = null,
    public val enableIPForwarding: Boolean? = null,
    public val ipConfigurations: List<VirtualMachineNetworkInterfaceIPConfigurationResponse>,
    public val name: String,
    public val networkSecurityGroup: SubResourceResponse? = null,
    public val primary: Boolean? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.VirtualMachineNetworkInterfaceConfigurationResponse):
            VirtualMachineNetworkInterfaceConfigurationResponse =
            VirtualMachineNetworkInterfaceConfigurationResponse(
                deleteOption = javaType.deleteOption().map({ args0 -> args0 }).orElse(null),
                disableTcpStateTracking = javaType.disableTcpStateTracking().map({ args0 -> args0 }).orElse(null),
                dnsSettings = javaType.dnsSettings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                dscpConfiguration = javaType.dscpConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                enableAcceleratedNetworking = javaType.enableAcceleratedNetworking().map({ args0 ->
                    args0
                }).orElse(null),
                enableFpga = javaType.enableFpga().map({ args0 -> args0 }).orElse(null),
                enableIPForwarding = javaType.enableIPForwarding().map({ args0 -> args0 }).orElse(null),
                ipConfigurations = javaType.ipConfigurations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineNetworkInterfaceIPConfigurationResponse.Companion.toKotlin(args0)
                    })
                }),
                name = javaType.name(),
                networkSecurityGroup = javaType.networkSecurityGroup().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                primary = javaType.primary().map({ args0 -> args0 }).orElse(null),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/compute/kotlin/outputs/VirtualMachineNetworkInterfaceConfigurationResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.compute.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Describes a virtual machine network interface configurations.
 * @property deleteOption Specify what happens to the network interface when the VM is deleted
 * @property disableTcpStateTracking Specifies whether the network interface is disabled for tcp state tracking.
 * @property dnsSettings The dns settings to be applied on the network interfaces.
 * @property dscpConfiguration
 * @property enableAcceleratedNetworking Specifies whether the network interface is accelerated networking-enabled.
 * @property enableFpga Specifies whether the network interface is FPGA networking-enabled.
 * @property enableIPForwarding Whether IP forwarding enabled on this NIC.
 * @property ipConfigurations Specifies the IP configurations of the network interface.
 * @property name The network interface configuration name.
 * @property networkSecurityGroup The network security group.
 * @property primary Specifies the primary network interface in case the virtual machine has more than 1 network interface.
 */
public data class VirtualMachineNetworkInterfaceConfigurationResponse(
    public val deleteOption: String? = null,
    public val disableTcpStateTracking: Boolean? = null,
    public val dnsSettings: VirtualMachineNetworkInterfaceDnsSettingsConfigurationResponse? = null,
    public val dscpConfiguration: SubResourceResponse? = null,
    public val enableAcceleratedNetworking: Boolean? = null,
    public val enableFpga: Boolean? = null,
    public val enableIPForwarding: Boolean? = null,
    public val ipConfigurations: List<VirtualMachineNetworkInterfaceIPConfigurationResponse>,
    public val name: String,
    public val networkSecurityGroup: SubResourceResponse? = null,
    public val primary: Boolean? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.compute.outputs.VirtualMachineNetworkInterfaceConfigurationResponse): VirtualMachineNetworkInterfaceConfigurationResponse =
            VirtualMachineNetworkInterfaceConfigurationResponse(
                deleteOption = javaType.deleteOption().map({ args0 -> args0 }).orElse(null),
                disableTcpStateTracking = javaType.disableTcpStateTracking().map({ args0 -> args0 }).orElse(null),
                dnsSettings = javaType.dnsSettings().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineNetworkInterfaceDnsSettingsConfigurationResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                dscpConfiguration = javaType.dscpConfiguration().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                enableAcceleratedNetworking = javaType.enableAcceleratedNetworking().map({ args0 ->
                    args0
                }).orElse(null),
                enableFpga = javaType.enableFpga().map({ args0 -> args0 }).orElse(null),
                enableIPForwarding = javaType.enableIPForwarding().map({ args0 -> args0 }).orElse(null),
                ipConfigurations = javaType.ipConfigurations().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.VirtualMachineNetworkInterfaceIPConfigurationResponse.Companion.toKotlin(args0)
                    })
                }),
                name = javaType.name(),
                networkSecurityGroup = javaType.networkSecurityGroup().map({ args0 ->
                    args0.let({ args0 ->
                        com.pulumi.azurenative.compute.kotlin.outputs.SubResourceResponse.Companion.toKotlin(args0)
                    })
                }).orElse(null),
                primary = javaType.primary().map({ args0 -> args0 }).orElse(null),
            )
    }
}
